#ifndef BITMAPIMAGE__H
#define BITMAPIMAGE__H

#include <string>

#include <fstream>

using namespace std;

#include "Matrix.h"
#include "Image.h"
#include "Vector.h"

class BitmapImage : public Image {
private:

   char identifier[2];
   unsigned long fileSize;
   unsigned long reserved;
   unsigned long offset;
   unsigned long headerLength;
   unsigned long width;
   unsigned long height;
   unsigned short planes;
   unsigned short bitsPerPixel;
   unsigned long compression;
   unsigned long bitmapSize;
   unsigned long hResolution;
   unsigned long vResolution;
   unsigned long colors;
   unsigned long importantColors;
   
   Matrix< unsigned char > *redChannel;
   Matrix< unsigned char > *greenChannel;
   Matrix< unsigned char > *blueChannel;

   unsigned short readShort( ifstream &input );
   unsigned long readLong( ifstream &input );
   void writeShort( unsigned short s, ofstream &out );
   void writeLong( unsigned long l, ofstream &out );

public:
   BitmapImage() { redChannel = greenChannel = blueChannel = 0; }
   BitmapImage( ifstream &input );
   BitmapImage( int w, int h );
   ~BitmapImage();

   Matrix< unsigned char > &getRed() { return *redChannel; };
   Matrix< unsigned char > &getBlue() { return *blueChannel; };
   Matrix< unsigned char > &getGreen() { return *greenChannel; };

   inline void set( int x, int y, Color pixel );
   void set( int i, int j, unsigned char r, unsigned char g, unsigned char b );
   void output( ofstream &output );

   int getRows() { return redChannel->getRows(); };
   int getColumns() { 
      return redChannel->getColumns(); };
};

#endif