#include <fstream>
#include <iostream>

using namespace std;

#include "BitmapImage.h"
#include "ColorMap.h"

int main( int argc, char *args[] ) {

#ifdef WIN32
   cout << "WIN32" << endl;
#else
   cout << "UNIX" << endl;
#endif

   // Make sure proper number of args.
   if (argc != 3) {
      cout << "Usage: " << args[0] << " <infile.txt> <outfile.bmp>" << endl;
      return 1;
   }

   // Open the input file.
   ifstream infile;
   infile.open( args[1], ios::in );
   if (!infile.good()) {
      cout << "Could not open " << args[1] << endl;
      return 1;
   }

   // Open the output file.
   ofstream outfile;
   outfile.open( args[2], ios::out|ios::binary );
   if (!outfile.good()) {
      cout << "Could not open " << args[2] << endl;
      return 1;
   }

   // Determine grid size.
   int width, height, j, i, k=0;
   float value; 

   infile >> width >> height;

   // Determine colormap bounds.
   ColorMap colorMap;
   Matrix< float > matrix( width, height );
   for (j=0;j<width;++j) {
      for (i=0;i<height;++i) {
         infile >> value;
         colorMap.bound( value );

         matrix.get(j,i) = value;
      }
   }
   infile.close();

   cout << "Min: " << colorMap.getMinValue() << " Max: " << colorMap.getMaxValue() << endl;

   // Apply colormap to each element.
   BitmapImage image( width, height );
   for (j=0;j<width;++j) {
      for (i=0;i<height;++i) {
         image.set( i, j, colorMap.getColor( matrix.get(i,j) ) );
      }
   }

   image.output( outfile );
}